==> kea-docs-2.0.0-2-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/de/d05/classisc_1_1http_1_1HttpConnection.js <==
var classisc_1_1http_1_1HttpConnection =
[
    [ "Transaction", "d1/d5e/classisc_1_1http_1_1HttpConnection_1_1Transaction.html", "d1/d5e/classisc_1_1http_1_1HttpConnection_1_1Transaction" ],
    [ "TransactionPtr", "de/d05/classisc_1_1http_1_1HttpConnection.html#a4eb33968081c8dde733fff9c98dbd098", null ],
    [ "HttpConnection", "de/d05/classisc_1_1http_1_1HttpConnection.html#a9c0eaf7020db2f64a9652e070f8fee67", null ],
    [ "~HttpConnection", "de/d05/classisc_1_1http_1_1HttpConnection.html#afadb1c2f414c714b632ff9f6ee24ce1d", null ],
    [ "acceptorCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#a48e1c7370c1bb25bbb7aa5954f24ca6c", null ],
    [ "asyncAccept", "de/d05/classisc_1_1http_1_1HttpConnection.html#ac3a0b49efe264faa7e4fbdf2fd34ac5a", null ],
    [ "asyncSendResponse", "de/d05/classisc_1_1http_1_1HttpConnection.html#a7f17939e94b42f315d406e566afb75ee", null ],
    [ "close", "de/d05/classisc_1_1http_1_1HttpConnection.html#a9f6ac40edd8ca11dc81a01c466972961", null ],
    [ "doHandshake", "de/d05/classisc_1_1http_1_1HttpConnection.html#a7efc17781e9e6c0a66e881acf743c671", null ],
    [ "doRead", "de/d05/classisc_1_1http_1_1HttpConnection.html#a83c67ef65c371d06ec891c12c3404bf7", null ],
    [ "doWrite", "de/d05/classisc_1_1http_1_1HttpConnection.html#a96c7be6d0f6f22a05a78016673a8e622", null ],
    [ "getRemoteEndpointAddressAsText", "de/d05/classisc_1_1http_1_1HttpConnection.html#aa8a8a3999789e9716844d66d564f2eb0", null ],
    [ "handshakeCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#ab014b6b6d70716ea4e87b66706a72353", null ],
    [ "idleTimeoutCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#abb18f21ef367d9875742cd96f101c810", null ],
    [ "requestTimeoutCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#ac6353858a706cfa9373d5754af335212", null ],
    [ "setupIdleTimer", "de/d05/classisc_1_1http_1_1HttpConnection.html#a50efc79738cc40b2e7bed77a67eb2319", null ],
    [ "setupRequestTimer", "de/d05/classisc_1_1http_1_1HttpConnection.html#a981ceb9e9a5e32d48af0f6d5e0d9718e", null ],
    [ "shutdown", "de/d05/classisc_1_1http_1_1HttpConnection.html#a9dce5bf8a89058ef562e7774de42c47a", null ],
    [ "shutdownCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#a9efdf5d49a9a511cf10fc7b12f5a3059", null ],
    [ "shutdownConnection", "de/d05/classisc_1_1http_1_1HttpConnection.html#af32b2deffcdcb510af8e3f1d0baa9690", null ],
    [ "socketReadCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#a1ae7ac7f848735169ddb1ea580252c00", null ],
    [ "socketWriteCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#a71cc7a9517fc8fb87abf0c5fb9134234", null ],
    [ "stopThisConnection", "de/d05/classisc_1_1http_1_1HttpConnection.html#aa2addc933d8437c3e095bd0018ee8c3c", null ],
    [ "acceptor_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a869c25977cf88fa252b4a23a3ceac6fe", null ],
    [ "acceptor_callback_", "de/d05/classisc_1_1http_1_1HttpConnection.html#adb16593885b3376f78759a71a4d777e8", null ],
    [ "connection_pool_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a0f95515f82d28cdd1f16a6e959a4f900", null ],
    [ "idle_timeout_", "de/d05/classisc_1_1http_1_1HttpConnection.html#abe992f1be6b607d4f99e334778775ebd", null ],
    [ "request_timeout_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ae4986514262fbbbc1a4514551ece168e", null ],
    [ "request_timer_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ad2e1d02fed93cab6d8f7c59dc26c7eab", null ],
    [ "response_creator_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ab90a2c149132815eb83db53391dbd4c6", null ],
    [ "tcp_socket_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ac411ee1da55de5f567cba3c1cf334996", null ],
    [ "tls_context_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a1c688fa4a93261cbdb85fd17cfcaab57", null ],
    [ "tls_socket_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a8bdccfcbe8cb0c203f6b57b41166a753", null ]
];

==> kea-docs-3.0.0-6-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/de/d05/classisc_1_1http_1_1HttpConnection.js <==
var classisc_1_1http_1_1HttpConnection =
[
    [ "Transaction", "d1/d5e/classisc_1_1http_1_1HttpConnection_1_1Transaction.html", "d1/d5e/classisc_1_1http_1_1HttpConnection_1_1Transaction" ],
    [ "TransactionPtr", "de/d05/classisc_1_1http_1_1HttpConnection.html#a4eb33968081c8dde733fff9c98dbd098", null ],
    [ "HttpConnection", "de/d05/classisc_1_1http_1_1HttpConnection.html#aa68902aaf53bfc5e01bbbc98f8170430", null ],
    [ "~HttpConnection", "de/d05/classisc_1_1http_1_1HttpConnection.html#afadb1c2f414c714b632ff9f6ee24ce1d", null ],
    [ "acceptorCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#a48e1c7370c1bb25bbb7aa5954f24ca6c", null ],
    [ "addExternalSockets", "de/d05/classisc_1_1http_1_1HttpConnection.html#acade87d37eef54c78de15332428c1d1a", null ],
    [ "asyncAccept", "de/d05/classisc_1_1http_1_1HttpConnection.html#ac3a0b49efe264faa7e4fbdf2fd34ac5a", null ],
    [ "asyncSendResponse", "de/d05/classisc_1_1http_1_1HttpConnection.html#a7f17939e94b42f315d406e566afb75ee", null ],
    [ "clearWatchSocket", "de/d05/classisc_1_1http_1_1HttpConnection.html#a5b93f3e2bd24dd7bde59ab9f8d2073b9", null ],
    [ "close", "de/d05/classisc_1_1http_1_1HttpConnection.html#a9f6ac40edd8ca11dc81a01c466972961", null ],
    [ "closeWatchSocket", "de/d05/classisc_1_1http_1_1HttpConnection.html#a0196c7ec76bb84d2b894ba8c93758c80", null ],
    [ "doHandshake", "de/d05/classisc_1_1http_1_1HttpConnection.html#a7efc17781e9e6c0a66e881acf743c671", null ],
    [ "doRead", "de/d05/classisc_1_1http_1_1HttpConnection.html#a83c67ef65c371d06ec891c12c3404bf7", null ],
    [ "doWrite", "de/d05/classisc_1_1http_1_1HttpConnection.html#a96c7be6d0f6f22a05a78016673a8e622", null ],
    [ "getRemoteEndpointAddressAsText", "de/d05/classisc_1_1http_1_1HttpConnection.html#aa8a8a3999789e9716844d66d564f2eb0", null ],
    [ "handshakeCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#ab014b6b6d70716ea4e87b66706a72353", null ],
    [ "idleTimeoutCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#abb18f21ef367d9875742cd96f101c810", null ],
    [ "markWatchSocketReady", "de/d05/classisc_1_1http_1_1HttpConnection.html#a3eddfcb4d179944f10747a90655a02ab", null ],
    [ "recordParameters", "de/d05/classisc_1_1http_1_1HttpConnection.html#a430fdd8f6781b44be00530d7c87ee23f", null ],
    [ "requestTimeoutCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#ac6353858a706cfa9373d5754af335212", null ],
    [ "setupIdleTimer", "de/d05/classisc_1_1http_1_1HttpConnection.html#a50efc79738cc40b2e7bed77a67eb2319", null ],
    [ "setupRequestTimer", "de/d05/classisc_1_1http_1_1HttpConnection.html#a981ceb9e9a5e32d48af0f6d5e0d9718e", null ],
    [ "shutdown", "de/d05/classisc_1_1http_1_1HttpConnection.html#a9dce5bf8a89058ef562e7774de42c47a", null ],
    [ "shutdownCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#a9efdf5d49a9a511cf10fc7b12f5a3059", null ],
    [ "shutdownConnection", "de/d05/classisc_1_1http_1_1HttpConnection.html#af32b2deffcdcb510af8e3f1d0baa9690", null ],
    [ "socketReadCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#a1ae7ac7f848735169ddb1ea580252c00", null ],
    [ "socketWriteCallback", "de/d05/classisc_1_1http_1_1HttpConnection.html#a71cc7a9517fc8fb87abf0c5fb9134234", null ],
    [ "stopThisConnection", "de/d05/classisc_1_1http_1_1HttpConnection.html#aa2addc933d8437c3e095bd0018ee8c3c", null ],
    [ "acceptor_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a869c25977cf88fa252b4a23a3ceac6fe", null ],
    [ "acceptor_callback_", "de/d05/classisc_1_1http_1_1HttpConnection.html#adb16593885b3376f78759a71a4d777e8", null ],
    [ "connection_pool_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a1afc5777899b83860f1d38b552b0f50e", null ],
    [ "defer_shutdown_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a96f2459668c7e4e94b42d4403a5a41a7", null ],
    [ "idle_timeout_", "de/d05/classisc_1_1http_1_1HttpConnection.html#abe992f1be6b607d4f99e334778775ebd", null ],
    [ "io_service_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a3c01505bc360fa3eed4a8292f21462e8", null ],
    [ "request_timeout_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ae4986514262fbbbc1a4514551ece168e", null ],
    [ "request_timer_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ad2e1d02fed93cab6d8f7c59dc26c7eab", null ],
    [ "response_creator_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ab90a2c149132815eb83db53391dbd4c6", null ],
    [ "tcp_socket_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ac411ee1da55de5f567cba3c1cf334996", null ],
    [ "tls_context_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a1c688fa4a93261cbdb85fd17cfcaab57", null ],
    [ "tls_socket_", "de/d05/classisc_1_1http_1_1HttpConnection.html#a8bdccfcbe8cb0c203f6b57b41166a753", null ],
    [ "use_external_", "de/d05/classisc_1_1http_1_1HttpConnection.html#aaeda36d4b50ccc66721641c09bab5637", null ],
    [ "watch_socket_", "de/d05/classisc_1_1http_1_1HttpConnection.html#ade9625faa1cb4d862a71eb4cb88c9fe1", null ]
];
